DuctJunction
============

.. todo:: Document :py:class:`contamxpy.DuctJunction` flags.
    
.. todo:: 
    :class:`contamxpy.DuctJunction`
    Why is there an envIndex property?
    ContamW does not provide for wind pressure to be specified for Duct Junctions.
    Coordinates are provided for Junctions in ContamW for use in 1D Zones. Is wind pressure
    accounted for at Leaks in Duct Junctions???

.. todo:: 
    :class:`contamxpy.DuctJunction`
    All terminals are junctions, but not all junctions are terminals.
    Separate them into different lists using flags?

.. autoclass:: contamxpy.DuctJunction
    :members:
